SEAPY Documentation
===================



:mod:`seapy` -- General tools for working with ocean fields
***********************************************************


.. automodule:: seapy.__init__
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: seapy.lib
   :members:
   :undoc-members:
   :show-inheritance:


:mod:`cdl_parser` -- Read CDL files to generate NetCDF Catalog
--------------------------------------------------------------
.. automodule:: seapy.cdl_parser
   :members:
   :undoc-members:
   :show-inheritance:


:mod:`environ` -- Load OS Environment Variables
-----------------------------------------------
.. autoclass:: seapy.environ
   :members:
   :undoc-members:
   :show-inheritance:


:mod:`filt` -- Spectral filter of time-series data
----------------------------------------------------
.. automodule:: seapy.filt
   :members:
   :undoc-members:
   :show-inheritance:


:mod:`hawaii` -- Mapping subclass for Hawaii
--------------------------------------------
.. autoclass:: seapy.hawaii
   :members:
   :undoc-members:
   :show-inheritance:


:mod:`mapping` -- Mapping toolkit for basemap
---------------------------------------------
.. autoclass:: seapy.mapping
   :members:
   :undoc-members:
   :show-inheritance:


:mod:`oa` -- Objective Analysis Interpolation
---------------------------------------------
.. automodule:: seapy.oa
   :members:
   :undoc-members:
   :show-inheritance:


:mod:`plot` -- Simple Plotting wrappers
---------------------------------------
.. automodule:: seapy.plot
   :members:
   :undoc-members:
   :show-inheritance:


:mod:`progressbar` -- Keep User informed of progress
----------------------------------------------------
.. automodule:: seapy.progressbar
   :members:
   :undoc-members:
   :show-inheritance:


:mod:`qserver` -- Manage multiple processes
-------------------------------------------
.. autoclass:: seapy.qserver.task
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: seapy.qserver.os_task
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: seapy.qserver
   :members:
   :undoc-members:
   :show-inheritance:


:mod:`tide` -- Generate and Process tidal data
----------------------------------------------
.. automodule:: seapy.tide
   :members:
   :undoc-members:
   :show-inheritance:

:mod:`tidal_energy` -- Compute Baroclinic Energy of Tides
---------------------------------------------------------
.. automodule:: seapy.tidal_energy
   :members:
   :undoc-members:
   :show-inheritance:

..
   .. autoclass:: seapy.tidal_energy
      :members:
      :undoc-members:
      :show-inheritance:


:mod:`timeout` -- Set limits to processes
-----------------------------------------
.. automodule:: seapy.timeout
   :members:
   :undoc-members:
   :show-inheritance:


